# home template

The templates/maillib/home.html template contains an email form where the user can enter the details for the email they want to send. Here is how it look:

     1{% extends '_partials/base.html' %}
     2
     3
     4{% block title %}
     5  Home
     6{% endblock %}
     7
     8{% load static %}
     9
    10
    11{% block content %}
    12<h1>Home</h1>
    13<div class="formcarry-container">
    14  {% include '_partials/messages.html' %}
    15  <form method="post" action={% url 'home' %} class="formcarry-form">
    16      {% csrf_token %}
    17    <!-- <label for="email">Your API Key</label>
    18    <input type="text" id="email" name="apiKey" required /> -->
    19
    20    <label for="fullName">Your Name</label>
    21    <input type="text" id="fullName" name="fullName" required />
    22
    23    <label for="fromEmail">Your Email Address</label>
    24    <input type="email" id="fromEmail" name="fromEmail" required />
    25
    26    <label for="toName">Recepient's Name</label>
    27    <input type="toName" id="toName" name="toName" required />
    28
    29    <label for="email">Target Email Address</label>
    30    <input type="email" id="toEmail" name="toEmail" required />
    31
    32    <label for="subject">Subject</label>
    33    <input type="text" id="subject" name="subject" required />
    34
    35    <label for="message">Your Message</label>
    36    <textarea name="message" id="message" cols="30" rows="10"></textarea>
    37
    38    <button type="submit">Send</button>
    39  </form>
    40</div>
    41
    42{% endblock %}